BEGIN {
  use strict; use warnings;
  unless(eval q{ use 5.008001; 1}) {
    print "Perl 5.008001 or better required\n";
    exit;
  }
}

# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.012.
use strict;
use warnings;

use Module::Build 0.28;
use lib qw{inc}; use My::ModuleBuild;

my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28",
    "autodie" => 0,
    "perl" => "5.008001"
  },
  "dist_abstract" => "parse directory listing using ftpparse from ftpcopy",
  "dist_author" => [
    "Graham Ollis <plicease\@cpan.org>"
  ],
  "dist_name" => "File-Listing-Ftpcopy",
  "dist_version" => "0.09",
  "license" => "gpl",
  "module_name" => "File::Listing::Ftpcopy",
  "recursive_test_files" => 1,
  "requires" => {
    "Math::Int64" => "0.28",
    "perl" => "5.008001"
  },
  "test_requires" => {
    "POSIX" => 0,
    "Test2::V0" => "0.000060",
    "perl" => "5.008001"
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28",
  "POSIX" => 0,
  "Test2::V0" => "0.000060",
  "perl" => "5.008001"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = My::ModuleBuild->new(%module_build_args);


$build->create_build_script;
